Asyncio high level UDP sockets
==============================

Asyncio high level UDP sockets.

Project homepage: https://github.com/eerimoq/asyncudp

Documentation: https://asyncudp.readthedocs.org/en/latest

Installation
============

.. code-block:: python

   $ pip install asyncudp

Test
====

.. code-block::

   $ python3 -m unittest
